import { DiscussionSchema } from "@gitbeaker/rest"

import type { Gitlab } from "../types"
import GitlabBaseService from "./base"

class Discussions extends GitlabBaseService {
  /**
   * 获取合并请求的讨论列表。IID。
   * @returns {Promise<DiscussionSchema[]>} 返回包含讨论列表的Promise。
   */
  async getList(): Promise<DiscussionSchema[]> {
    const URL = `/projects/${this.project_id}/merge_requests/${this.merge_request_iid}/discussions`
    return this.errorWarp<DiscussionSchema[]>(() => this.get(URL), [])
  }

  /**
   * 创建合并请求的讨论。
   * @param {string} body - 讨论内容。
   * @param {CreateRangeDiscussionPosition} position - 讨论位置。
   * @returns {Promise<DiscussionSchema | null>} 返回包含创建的讨论的Promise。
   */
  async create2Mr(
    body: string,
    position: Gitlab.CreateRangeDiscussionPosition
  ): Promise<DiscussionSchema | null> {
    const URL = `/projects/${this.project_id}/merge_requests/${this.merge_request_iid}/discussions`
    return this.errorWarp<DiscussionSchema>(
      () => this.post(URL, { body, position }),
      null
    )
  }
}

export default Discussions
